==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AParameter.h <==
// public final class soot.jimple.parser.node.AParameter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d611f20f92d8417 soot_jimple_parser_node_AParameter
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class da2d8f39caaaaf34 soot_jimple_parser_node_PParameter

// header file dependencies
// @dep_header soot_jimple_parser_node_PParameter

#include "soot/jimple/parser/node/PParameter.h"

#ifndef _JC_soot_jimple_parser_node_AParameter_H_
#define _JC_soot_jimple_parser_node_AParameter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNonvoidType$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AParameter$sub_refs	_jc_soot_jimple_parser_node_AParameter$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AParameter$sub_nonrefs	_jc_soot_jimple_parser_node_AParameter$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AParameter$refs	_jc_soot_jimple_parser_node_AParameter$refs;
typedef struct _jc_soot_jimple_parser_node_AParameter$nonrefs	_jc_soot_jimple_parser_node_AParameter$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AParameter$object	_jc_soot_jimple_parser_node_AParameter$object;

typedef const struct _jc_soot_jimple_parser_node_AParameter$vmethods	_jc_soot_jimple_parser_node_AParameter$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AParameter$vtable	_jc_soot_jimple_parser_node_AParameter$vtable;
typedef const struct _jc_soot_jimple_parser_node_AParameter$vtype	_jc_soot_jimple_parser_node_AParameter$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AParameter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
extern void _jc_soot_jimple_parser_node_AParameter$method$_init$2c73afb22871bbc7(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AParameter$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AParameter$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
extern struct _jc_soot_jimple_parser_node_PNonvoidType$object *_jc_soot_jimple_parser_node_AParameter$method$getNonvoidType$be101fb7b05903db(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
extern void _jc_soot_jimple_parser_node_AParameter$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AParameter$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AParameter$method$setNonvoidType$cce5049cab1accc6(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AParameter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$getNonvoidType$be101fb7b05903db;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$setNonvoidType$cce5049cab1accc6;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AParameter$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*(*getNonvoidType$be101fb7b05903db)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNonvoidType$cce5049cab1accc6)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AParameter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameter$vmethods	soot_jimple_parser_node_PParameter;
	_jc_soot_jimple_parser_node_AParameter$vmethods	soot_jimple_parser_node_AParameter;
};

// Vtype
struct _jc_soot_jimple_parser_node_AParameter$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AParameter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AParameter$sub_refs {
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*__5fnonvoidType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AParameter$refs {
    _jc_soot_jimple_parser_node_AParameter$sub_refs	soot_jimple_parser_node_AParameter;
    _jc_soot_jimple_parser_node_PParameter$sub_refs	soot_jimple_parser_node_PParameter;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AParameter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AParameter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameter$sub_nonrefs	soot_jimple_parser_node_PParameter;
    _jc_soot_jimple_parser_node_AParameter$sub_nonrefs	soot_jimple_parser_node_AParameter;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AParameter$object {
	_jc_soot_jimple_parser_node_AParameter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AParameter$vtype	*vtype;
	_jc_soot_jimple_parser_node_AParameter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AParameter$vtype _jc_soot_jimple_parser_node_AParameter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AParameter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AParameter$class_object;

#endif	/* _JC_soot_jimple_parser_node_AParameter_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AParameter.h <==
// public final class soot.jimple.parser.node.AParameter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d611f20f92d8417 soot_jimple_parser_node_AParameter
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class da2d8f39caaaaf34 soot_jimple_parser_node_PParameter

// header file dependencies
// @dep_header soot_jimple_parser_node_PParameter

#include "soot/jimple/parser/node/PParameter.h"

#ifndef _JC_soot_jimple_parser_node_AParameter_H_
#define _JC_soot_jimple_parser_node_AParameter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PNonvoidType$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AParameter$sub_refs	_jc_soot_jimple_parser_node_AParameter$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AParameter$sub_nonrefs	_jc_soot_jimple_parser_node_AParameter$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AParameter$refs	_jc_soot_jimple_parser_node_AParameter$refs;
typedef struct _jc_soot_jimple_parser_node_AParameter$nonrefs	_jc_soot_jimple_parser_node_AParameter$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AParameter$object	_jc_soot_jimple_parser_node_AParameter$object;

typedef const struct _jc_soot_jimple_parser_node_AParameter$vmethods	_jc_soot_jimple_parser_node_AParameter$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AParameter$vtable	_jc_soot_jimple_parser_node_AParameter$vtable;
typedef const struct _jc_soot_jimple_parser_node_AParameter$vtype	_jc_soot_jimple_parser_node_AParameter$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AParameter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AParameter$method$_init$2c73afb22871bbc7(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AParameter$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AParameter$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PNonvoidType$object *_jc_soot_jimple_parser_node_AParameter$method$getNonvoidType$be101fb7b05903db(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AParameter$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AParameter$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AParameter$method$setNonvoidType$cce5049cab1accc6(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AParameter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$getNonvoidType$be101fb7b05903db;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$setNonvoidType$cce5049cab1accc6;
extern _jc_method _jc_soot_jimple_parser_node_AParameter$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AParameter$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*(*getNonvoidType$be101fb7b05903db)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNonvoidType$cce5049cab1accc6)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *, struct _jc_soot_jimple_parser_node_PNonvoidType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AParameter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AParameter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameter$vmethods	soot_jimple_parser_node_PParameter;
	_jc_soot_jimple_parser_node_AParameter$vmethods	soot_jimple_parser_node_AParameter;
};

// Vtype
struct _jc_soot_jimple_parser_node_AParameter$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AParameter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AParameter$sub_refs {
	struct _jc_soot_jimple_parser_node_PNonvoidType$object	*__5fnonvoidType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AParameter$refs {
    _jc_soot_jimple_parser_node_AParameter$sub_refs	soot_jimple_parser_node_AParameter;
    _jc_soot_jimple_parser_node_PParameter$sub_refs	soot_jimple_parser_node_PParameter;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AParameter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AParameter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameter$sub_nonrefs	soot_jimple_parser_node_PParameter;
    _jc_soot_jimple_parser_node_AParameter$sub_nonrefs	soot_jimple_parser_node_AParameter;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AParameter$object {
	_jc_soot_jimple_parser_node_AParameter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AParameter$vtype	*vtype;
	_jc_soot_jimple_parser_node_AParameter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AParameter$vtype _jc_soot_jimple_parser_node_AParameter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AParameter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AParameter$class_object;

#endif	/* _JC_soot_jimple_parser_node_AParameter_H_ */
